@@ -11,4 +11,7 @@
 #include "pomp_defines.h"
 #include "pomp_decls.h"
 
+#define err(...) errorcall(R_NilValue,__VA_ARGS__)
+#define warn(...) warningcall(R_NilValue,__VA_ARGS__)
+
 #endif
