@@ -248,7 +248,7 @@ SEXP pomp_desolve_setup (SEXP object, SEXP x0, SEXP params, SEXP gnsi) {
 
   default: // #nocov
 
-    errorcall(R_NilValue,"in 'pomp_desolve_setup': unrecognized 'mode'"); // # nocov
+    err("in 'pomp_desolve_setup': unrecognized 'mode'"); // # nocov
 
   }
 
@@ -282,7 +282,7 @@ void pomp_vf_eval (int *neq, double *t, double *y, double *ydot, double *yout, i
 
   default: // #nocov
 
-    errorcall(R_NilValue,"in 'pomp_vf_eval': unrecognized 'mode'"); // # nocov
+    err("in 'pomp_vf_eval': unrecognized 'mode'"); // # nocov
 
   break;
 
@@ -334,7 +334,7 @@ void pomp_desolve_takedown (void) {
 
   default: // #nocov
 
-    errorcall(R_NilValue,"in 'pomp_desolve_takedown': unrecognized 'mode'"); // # nocov
+    err("in 'pomp_desolve_takedown': unrecognized 'mode'"); // # nocov
 
   break;
 
